@@ -19,7 +19,7 @@
 #' used arguments} \item{call}{\link{call} the function call}
 #'
 #' The output should be accessed using the function
-#' \code{\link{get_RLum.Results}}
+#' \code{\link{get_RLum}}
 #' @section Function version: 0.2
 #' @author Christoph Burow, University of Cologne (Germany)
 #' @seealso \code{\link{pchisq}}
@@ -49,7 +49,7 @@ calc_HomogeneityTest <- function(
            'data.frame' or 'RLum.Results'!")
     } else {
       if(is(data, "RLum.Results") == TRUE){
-        data <- get_RLum.Results(data, signature(object = "De.values"))
+        data <- get_RLum(data, signature(object = "De.values"))
 
       }
     }
@@ -113,7 +113,8 @@ calc_HomogeneityTest <- function(
   call<- sys.call()
   args<- list(log=log)
 
-  newRLumResults.calc_HomogeneityTest <- set_RLum.Results(
+  newRLumResults.calc_HomogeneityTest <- set_RLum(
+    class = "RLum.Results",
     data = list(
       summary=summary,
       data=data,
