@@ -109,7 +109,7 @@
 #' (France)
 #' @seealso \code{\link{fit_LMCurve}}, \code{\link{plot}},\code{\link{nls}},
 #' \code{\linkS4class{RLum.Data.Curve}}, \code{\linkS4class{RLum.Results}},
-#' \code{\link{get_RLum.Results}}, \code{\link{nlsLM}}
+#' \code{\link{get_RLum}}, \code{\link[minpack.lm]{nlsLM}}
 #' @references Boetter-Jensen, L., McKeever, S.W.S., Wintle, A.G., 2003.
 #' Optically Stimulated Luminescence Dosimetry. Elsevier Science B.V.
 #'
@@ -283,12 +283,12 @@ fit_CWCurve<- function(
     if(fit.method == "LM"){
 
       ##try fit simple
-      fit.try<-suppressWarnings(try(nlsLM(fit.formula.simple(n.components),
+      fit.try<-suppressWarnings(try(minpack.lm::nlsLM(fit.formula.simple(n.components),
                                           data=values,
                                           start=c(I0,lambda),
                                           na.action = "na.exclude",
                                           trace = fit.trace,
-                                          control = nls.lm.control(
+                                          control = minpack.lm::nls.lm.control(
                                             maxiter = 500
                                           )),
                                     silent = TRUE
@@ -335,17 +335,25 @@ fit_CWCurve<- function(
       if(fit.method == "LM"){
 
         ##try fit simple
-        fit.try<-suppressWarnings(try(nlsLM(fit.formula(n.components),
+        fit.try<-suppressWarnings(try(minpack.lm::nlsLM(fit.formula(n.components),
                                             data=values,
                                             start=c(I0,lambda),
                                             trace = fit.trace,
                                             na.action = "na.exclude",
                                             lower = rep(0,n.components * 2),
-                                            control = nls.lm.control(
+                                            control = minpack.lm::nls.lm.control(
                                               maxiter = 500
                                             )),
                                       silent = TRUE))
-
+        
+        ## HACK: 
+        # minpack.lm::nlsLM() stores the 'lower' argument as class "call" rather
+        # than "numeric" as nls() does. Before running confint() on this object
+        # we overwrite the "lower" slot with the numeric values again. 
+        if (!inherits(fit.try, "try-error")) {
+          fit.try$call$lower <- rep(0,n.components * 2)
+        }
+        
       }else{
 
 
@@ -367,8 +375,7 @@ fit_CWCurve<- function(
 
       }#fit.method
     }
-
-
+    
     ##count failed attempts for fitting
     if(inherits(fit.try,"try-error")==FALSE){
 
@@ -652,7 +659,7 @@ fit_CWCurve<- function(
         seq(3,ncol(component.contribution.matrix),by=2),
         function(x){
 
-          rowDiffs(cbind(rev(component.contribution.matrix[,(x+1)]),
+          matrixStats::rowDiffs(cbind(rev(component.contribution.matrix[,(x+1)]),
                          component.contribution.matrix[,x]))
 
         })
@@ -793,7 +800,8 @@ fit_CWCurve<- function(
   ## Return Values
   ##============================================================================##
 
-  newRLumResults.fit_CWCurve <- set_RLum.Results(
+  newRLumResults.fit_CWCurve <- set_RLum(
+    class = "RLum.Results",
     data = list(
       fit = fit,
       output.table = output.table,
