@@ -14,7 +14,7 @@
 #' \bold{\code{plot.type = "plot.raster"}}\cr
 #'
 #' Uses the standard plot function for raster data from the package
-#' \code{\link{raster}}: \code{\link[raster]{plot}}. For each raster layer in a
+#' \code{\link[raster]{raster}}: \code{\link[raster]{plot}}. For each raster layer in a
 #' raster brick one plot is produced.
 #'
 #' Arguments that are passed through the function call:\cr
@@ -25,7 +25,7 @@
 #' \bold{\code{plot.type = "plotRGB"}}\cr
 #'
 #' Uses the function \code{\link[raster]{plotRGB}} from the
-#' \code{\link{raster}} package. Only one image plot is produced as all layers
+#' \code{\link[raster]{raster}} package. Only one image plot is produced as all layers
 #' in a brick a combined.  This plot type is useful to see whether any signal
 #' is recorded by the camera.\cr Arguments that are passed through the function
 #' call:\cr
@@ -61,7 +61,7 @@
 #' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne
 #' (France)
 #' @seealso \code{\linkS4class{RLum.Data.Image}}, \code{\link{plot}},
-#' \code{\link{plot_RLum}}, \code{\link{raster}},
+#' \code{\link{plot_RLum}}, \code{\link[raster]{raster}},
 #' @references -
 #' @keywords aplot
 #' @examples
@@ -108,10 +108,10 @@ plot_RLum.Data.Image <- function(
   {"Height [px]"}
 
   xlim <- if("xlim" %in% names(extraArgs)) {extraArgs$xlim} else
-  {c(0,dim(get_RLum.Data.Image(object))[2])}
+  {c(0,dim(get_RLum(object))[2])}
 
   ylim <- if("ylim" %in% names(extraArgs)) {extraArgs$ylim} else
-  {c(0,dim(get_RLum.Data.Image(object))[1])}
+  {c(0,dim(get_RLum(object))[1])}
 
   ##plotRGB::ext
   ext <- if("ext" %in% names(extraArgs)) {extraArgs$ext} else
@@ -127,7 +127,7 @@ plot_RLum.Data.Image <- function(
 
   ##plotRGB::maxpixels
   maxpixels <- if("maxpixels" %in% names(extraArgs)) {extraArgs$maxpixels} else
-  {dim(get_RLum.Data.Image(object))[1]*dim(get_RLum.Data.Image(object))[2]}
+  {dim(get_RLum(object))[1]*dim(get_RLum(object))[2]}
 
   ##plotRGB::alpha
   alpha <- if("alpha" %in% names(extraArgs)) {extraArgs$alpha} else
@@ -157,8 +157,8 @@ plot_RLum.Data.Image <- function(
     ## standard raster plotRGB (package raster)
     ## ==========================================================================#
 
-    plotRGB(
-      get_RLum.Data.Image(object),
+    raster::plotRGB(
+      get_RLum(object),
       main = main,
       axes = TRUE,
       xlab = xlab,
@@ -176,7 +176,7 @@ plot_RLum.Data.Image <- function(
     ## ==========================================================================#
   }else if(plot.type == "plot.raster"){
 
-    plot(get_RLum.Data.Image(object),
+    plot(get_RLum(object),
          main = main,
          xlim = xlim,
          ylim = ylim,
@@ -189,10 +189,10 @@ plot_RLum.Data.Image <- function(
     ## ==========================================================================#
   }else if(plot.type == "contour"){
 
-    for(i in 1:nlayers(get_RLum.Data.Image(object))){
+    for(i in 1:raster::nlayers(get_RLum(object))){
 
 
-      raster::contour(raster(get_RLum.Data.Image(object), layer = i),
+      raster::contour(raster::raster(get_RLum(object), layer = i),
                       main = main,
                       xlim = xlim,
                       ylim = ylim,
