@@ -10,17 +10,21 @@
 #'
 #' @param object \code{\linkS4class{Risoe.BINfileData}} (\bold{required}):
 #' input object to be stored in a bin file.
+#'
 #' @param file \code{\link{character}} (\bold{required}): file name and path of
 #' the output file\cr [WIN]: \code{writeR2BIN(object, "C:/Desktop/test.bin")},
 #' \cr [MAC/LINUX]: \code{writeR2BIN("/User/test/Desktop/test.bin")}
+#'
 #' @param version \code{\link{character}} (optional): version number for the
 #' output file. If no value is provided the highest version number from the
 #' \code{\linkS4class{Risoe.BINfileData}} is taken automatically.\cr\cr Note:
 #' This argument can be used to convert BIN-file versions.
+#'
 #' @param compatibility.mode \code{\link{logical}} (with default): this option
 #' recalculates the position values if necessary and set the max. value to 48.
-#' The old position number is appended as comment (e.gh. 'OP: 70). This option
+#' The old position number is appended as comment (e.g., 'OP: 70). This option
 #' accounts for potential compatibility problems with the Analyst software.
+#'
 #' @param txtProgressBar \link{logical} (with default): enables or disables
 #' \code{\link{txtProgressBar}}.
 #' @return Write a binary file.
@@ -39,13 +43,18 @@
 #' directly produced by the Risoe readers!\cr
 #'
 #' Implementation of support for version 07 could so far not properly tested.
-#' @section Function version: 0.3.1
+#' @section Function version: 0.3.2
+#'
 #' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne
 #' (France)
+#'
 #' @seealso \code{\link{readBIN2R}}, \code{\linkS4class{Risoe.BINfileData}},
 #' \code{\link{writeBin}}
+#'
 #' @references Duller, G., 2007. Analyst.
+#'
 #' @keywords IO
+#'
 #' @examples
 #'
 #'
@@ -68,7 +77,6 @@ writeR2BIN <- function(
   ##set supported BIN format version
   VERSION.supported <- as.raw(c(3, 4, 6, 7))
 
-
   # Check integrity ---------------------------------------------------------
 
   ##check if input object is of type 'Risoe.BINfileData'
@@ -78,6 +86,13 @@ writeR2BIN <- function(
 
   }
 
+  ##check if it fullfills the last definition
+  if(ncol(object@METADATA)!=71){
+
+    stop("[writeR2BIN()] The number of columns in your slot 'METADATA' does not fit to the latest definition. What you are probably trying to do is to export a Risoe.BINfileData object you generated by your own or you imported with an old package version some time ago. Please re-import the BIN-file using the function readBIN2R().")
+
+  }
+
   ##check if input file is of type 'character'
   if(is(file, "character") == FALSE){
 
@@ -91,11 +106,12 @@ writeR2BIN <- function(
   ##VERSION
 
   ##If missing version argument set to the highest value
-  if(missing(version) == TRUE){
+  if(missing(version)){
 
     version <- as.raw(max(as.numeric(object@METADATA[,"VERSION"])))
     version.original <- version
 
+
   }else{
 
     version.original <- as.raw(max(as.numeric(object@METADATA[,"VERSION"])))
@@ -132,12 +148,19 @@ writeR2BIN <- function(
 
   }
 
+  ##check whether this file can be exported without problems due to the latest specifications
+  if(ncol(object@METADATA) != 71){
+
+    stop("[writeR2BIN()] Your Risoe.BINfileData object seems not be compatible with the latest specification of this S4-class object. You are probably trying to export a Risoe.BINfileData from your workspace you produced manually ")
+
+  }
+
   ##Check if the BINfile object contains of unsupported versions
   if((as.raw(object@METADATA[1,"VERSION"]) %in% VERSION.supported) == FALSE ||
        version %in% VERSION.supported == FALSE){
 
     ##show error message
-    error.text <- paste("[writeR2BIN()] Error: Writing BIN-files in format version (",
+    error.text <- paste("[writeR2BIN()] Writing BIN-files in format version (",
                         object@METADATA[1,"VERSION"],") is currently not supported!
                         Supported version numbers are: ",
                         paste(VERSION.supported,collapse=", "),".",sep="")
@@ -342,7 +365,6 @@ writeR2BIN <- function(
     ##start loop for export BIN data
     while(ID<=n.records) {
 
-
       ##VERSION
       writeBin(as.raw(object@METADATA[ID,"VERSION"]),
                con,
@@ -892,17 +914,23 @@ writeR2BIN <- function(
       ##FNAME
       FNAME_SIZE <- as.integer(nchar(as.character(object@METADATA[ID,"FNAME"]), type="bytes"))
 
+        ##correct for case that this is of 0 length
+        if(length(FNAME_SIZE) == 0){FNAME_SIZE <- as.integer(0)}
+
       writeBin(FNAME_SIZE,
                con,
                size = 1,
                endian="little")
 
-      writeChar(as.character(object@METADATA[ID,"FNAME"]),
-                con,
-                nchars = FNAME_SIZE,
-                useBytes=TRUE,
-                eos = NULL)
-
+      if(FNAME_SIZE>0) {
+        writeChar(
+          as.character(object@METADATA[ID,"FNAME"]),
+          con,
+          nchars = FNAME_SIZE,
+          useBytes = TRUE,
+          eos = NULL
+        )
+      }
 
       if((100-FNAME_SIZE)>0){
         writeBin(raw(length = c(100-FNAME_SIZE)),
